#include "showplayer.h"


ShowPlayer::ShowPlayer(QWidget *parent) :
    QDialog(parent)
  , ui(new Ui::ShowPlayer)
{
    ui->setupUi(this);
    connect(ui->addCueButton, SIGNAL(clicked()), this, SLOT(onAddTrack()));
    connect(ui->goButton, SIGNAL(clicked()), this, SLOT(go()));
    filesLoaded = 0;
    currentStatus = Status::Iddle;
    for(int i = 0; i < MAX_LAYERS; i++)
       layersUsed[i] = -1;
    connect(ui->cueListWidget, SIGNAL(changeSelectedIndex(int)), this, SLOT(changeSelectedIndex(int)));
}

ShowPlayer::~ShowPlayer() {}

void ShowPlayer::onAddTrack() {
	ui->cueListWidget->createNewCueTrack();
}

void ShowPlayer::go()
{
    ui->activeCueNumber->display(lastIndex);
    CueTrack* current = ui->cueListWidget->getSelectedTrack();
	if (!current)
        return;
    if (current->audioLayer < 0)
		return;
    ui->activeCueLabel->setText(current->name.data());
    for (int i = 0; i < MAX_LAYERS; i++) {
        if (layersUsed[i] == -1) {
            layersUsed[i] = current->userNumber;
            break;
        }
    }
    if (!current->filePath.empty())
        emit uiLoadMedia(current->audioLayer, current->filePath.data());
    updateTrackStateInEngine(current);
    emit uiPlaybackChanged(current->audioLayer, current->status);
    filesLoaded++;
}

void ShowPlayer::updateTrackStateInEngine(CueTrack *track) {
    emit uiSliderChanged(track->audioLayer, Slider::Volume, track->volume * 655.35);
    emit uiSliderChanged(track->audioLayer, Slider::Pan, (track->pan + 1) * 128);
    emit uiSliderChanged(track->audioLayer, Slider::Pitch, track->pitch * 128);
    emit uiSliderChanged(track->audioLayer, Slider::Bus1, track->bus1 * 255 * 2.55);
    emit uiSliderChanged(track->audioLayer, Slider::Bus2, track->bus2 * 255 * 2.55);
}

void ShowPlayer::changeSelectedIndex(int i)
{
    CueTrack *t = ui->cueListWidget->getTrackAtIndex(i);
    ui->nextCueNumber->display(i);
    ui->nextCueLabel->setText(t->name.data());
    lastIndex = i;
}
